@@ -4,7 +4,6 @@ set -xeo pipefail
 
 systemctl stop podman.socket || :
 
-dnf erase podman -y
+dnf remove podman -y
 dnf copr enable rhcontainerbot/podman-next -y
 dnf install podman -y
-
