@@ -1,9 +1,5 @@
 """Podman client module."""
 
-import sys
-
-assert sys.version_info >= (3, 6), "Python 3.6 or greater is required."
-
 from podman.client import PodmanClient, from_env
 from podman.version import __version__
 
